@@ -638,7 +638,7 @@ TQPixmap board_2d::getChessman( const int &pos )
 	}
 	if( ( pos == premoveFrom ) || ( pos == premoveTo ) )
 	{
-		KIconEffect::semiTransparent( tmp );
+		TDEIconEffect::semiTransparent( tmp );
 	}
 	return tmp;
 }
