@@ -16,7 +16,7 @@
  ***************************************************************************/
 
 #include <tqregexp.h>
-#include <kmessagebox.h>
+#include <tdemessagebox.h>
 #include "match.moc"
 #include "board_base.h"
 #include "board_2d.h"
