@@ -723,7 +723,7 @@ TQString pgn::getword( void )
 bool pgn::open( const TQString &URL )
 {
 	close();
-	if( !KIO::NetAccess::download( URL, tempFile ) )
+	if( !TDEIO::NetAccess::download( URL, tempFile ) )
 		return FALSE;
 
 	File.setName( tempFile );
@@ -750,7 +750,7 @@ void pgn::close( void )
 	}
 	if( !tempFile.isEmpty() )
 	{
-		KIO::NetAccess::removeTempFile( tempFile );
+		TDEIO::NetAccess::removeTempFile( tempFile );
 		tempFile = "";
 	}
 }
