@@ -17,14 +17,14 @@
 
 #include "setpagedisplay.moc"
 #include <kstddirs.h>
-#include <kmessagebox.h>
+#include <tdemessagebox.h>
 #include <kcolordialog.h>
-#include <kfontdialog.h>
+#include <tdefontdialog.h>
 #include <tqstyle.h>
 #include <tqregexp.h>
 #include <kiconloader.h>
-#include <kfiledialog.h>
-#include <kio/netaccess.h>
+#include <tdefiledialog.h>
+#include <tdeio/netaccess.h>
 
 setPageDisplay::setPageDisplay(TQWidget *parent, resource *Rsrc  ) : TQVBoxLayout(parent)
 {	
@@ -99,7 +99,7 @@ void setPageDisplay::initTab1( void )
 	EDIT_SCID_Images->setText( Resource->SCID_Image_Path );
 	connect( EDIT_SCID_Images, TQT_SIGNAL( textChanged(const TQString&) ), this, TQT_SLOT( slot_SCID_Images(const TQString&) ) );
 	BUTTON_SCID_Images = new TQPushButton( GROUP_SCID_Images );
-	BUTTON_SCID_Images->setPixmap( Resource->LoadIcon( TQString( "fileopen" ), KIcon::Toolbar ) );
+	BUTTON_SCID_Images->setPixmap( Resource->LoadIcon( TQString( "document-open" ), TDEIcon::Toolbar ) );
 	connect( BUTTON_SCID_Images, TQT_SIGNAL( clicked() ), this, TQT_SLOT( slot_SCID_Images_Button() ) );
 
 	GROUP_General_Graphics = new TQGroupBox( 4,
@@ -156,7 +156,7 @@ void setPageDisplay::initTab1( void )
 ///////////////////////////////////////
 void setPageDisplay::initTab2( void )
 {
-	TQPixmap ColorsIcon( Resource->LoadIcon( TQString("colorize"), KIcon::Toolbar ) );
+	TQPixmap ColorsIcon( Resource->LoadIcon( TQString("colorize"), TDEIcon::Toolbar ) );
 	Tab2 = new TQFrame( TabParent );
 	Tab2->setMargin( margin );
 
@@ -239,12 +239,12 @@ void setPageDisplay::initTab2( void )
 ///////////////////////////////////////
 void setPageDisplay::slot_setDefault(void)
 {
-	Resource->FONT_Standard = KGlobalSettings::fixedFont();
-	Resource->FONT_PrivateTell = KGlobalSettings::fixedFont();
-	Resource->FONT_ChannelTell = KGlobalSettings::fixedFont();
-	Resource->FONT_Shout = KGlobalSettings::fixedFont();
-	Resource->FONT_Whisper = KGlobalSettings::fixedFont();
-	Resource->FONT_Notification = KGlobalSettings::fixedFont();
+	Resource->FONT_Standard = TDEGlobalSettings::fixedFont();
+	Resource->FONT_PrivateTell = TDEGlobalSettings::fixedFont();
+	Resource->FONT_ChannelTell = TDEGlobalSettings::fixedFont();
+	Resource->FONT_Shout = TDEGlobalSettings::fixedFont();
+	Resource->FONT_Whisper = TDEGlobalSettings::fixedFont();
+	Resource->FONT_Notification = TDEGlobalSettings::fixedFont();
 	Resource->COLOR_Background = Resource->COLOR_White;
 	Resource->COLOR_Standard = Resource->COLOR_Black;
 	Resource->COLOR_PrivateTell = TQColor( 128, 0, 128 );	// Purple
@@ -263,48 +263,48 @@ void setPageDisplay::slot_setDefault(void)
 ///////////////////////////////////////
 void setPageDisplay::slot_Font_Standard(void)
 {
-	int value = KFontDialog::getFont( Resource->FONT_Standard );
-	if( value != KFontDialog::Accepted ) return;
+	int value = TDEFontDialog::getFont( Resource->FONT_Standard );
+	if( value != TDEFontDialog::Accepted ) return;
 	resetSampleConsole();
 	rebuildConsole = TRUE;
 	emit enableApply();
 }
 void setPageDisplay::slot_Font_PrivateTell(void)
 {
-	int value = KFontDialog::getFont( Resource->FONT_PrivateTell );
-	if( value != KFontDialog::Accepted ) return;
+	int value = TDEFontDialog::getFont( Resource->FONT_PrivateTell );
+	if( value != TDEFontDialog::Accepted ) return;
 	resetSampleConsole();
 	rebuildConsole = TRUE;
 	emit enableApply();
 }
 void setPageDisplay::slot_Font_ChannelTell(void)
 {
-	int value = KFontDialog::getFont( Resource->FONT_ChannelTell );
-	if( value != KFontDialog::Accepted ) return;
+	int value = TDEFontDialog::getFont( Resource->FONT_ChannelTell );
+	if( value != TDEFontDialog::Accepted ) return;
 	resetSampleConsole();
 	rebuildConsole = TRUE;
 	emit enableApply();
 }
 void setPageDisplay::slot_Font_Shout(void)
 {
-	int value = KFontDialog::getFont( Resource->FONT_Shout );
-	if( value != KFontDialog::Accepted ) return;
+	int value = TDEFontDialog::getFont( Resource->FONT_Shout );
+	if( value != TDEFontDialog::Accepted ) return;
 	resetSampleConsole();
 	rebuildConsole = TRUE;
 	emit enableApply();
 }
 void setPageDisplay::slot_Font_Whisper(void)
 {
-	int value = KFontDialog::getFont( Resource->FONT_Whisper );
-	if( value != KFontDialog::Accepted ) return;
+	int value = TDEFontDialog::getFont( Resource->FONT_Whisper );
+	if( value != TDEFontDialog::Accepted ) return;
 	resetSampleConsole();
 	rebuildConsole = TRUE;
 	emit enableApply();
 }
 void setPageDisplay::slot_Font_Notification(void)
 {
-	int value = KFontDialog::getFont( Resource->FONT_Notification );
-	if( value != KFontDialog::Accepted ) return;
+	int value = TDEFontDialog::getFont( Resource->FONT_Notification );
+	if( value != TDEFontDialog::Accepted ) return;
 	resetSampleConsole();
 	rebuildConsole = TRUE;
 	emit enableApply();
